@@ -8,14 +8,12 @@ namespace MiX{
   const typename NodeList<charT,char_traits,xml_traits>::iterator Text<charT,char_traits,xml_traits>::dmy_it = NodeList<charT,char_traits,xml_traits>::iterator();
   
   template <class charT,class char_traits,class xml_traits>
-  XMLString<charT,char_traits,xml_traits> Text<charT,char_traits,xml_traits>::toString(bool is_indent,int indent_off)const{
-    if(is_indent){
-      string_type s;
-      insertIndent(indent_off,s,xml_traits::tab());
-      s += getValue(); s += xml_traits::crlf();
-      return s;
-    }
-    else return getValue();
+  XMLString<charT,char_traits,xml_traits> Text<charT,char_traits,xml_traits>::toString(bool is_indent,const string_type& idt,int indent_off)const{
+    std::basic_stringstream<charT,char_traits> ss;
+    ss << ( is_indent ? make_indent(indent_off,idt) : string_type() )
+       << getValue();
+    if( is_indent ) ss << xml_traits::crlf();
+    return ss.str();
   }
 
   
